import datetime


# 格林威治时间+8小时变为上海时间
def time_str_handler(utc_str, utc_format, shanghai_format):
	utc = datetime.datetime.strptime(utc_str, utc_format)
	shanghai = utc + datetime.timedelta(hours=8)
	shanghai = shanghai.strftime(shanghai_format)
	return shanghai


def localtime_str(str_format):
	now = datetime.datetime.now()
	return now.strftime(str_format)



from setuptools import setup, find_packages

str_version = '1.1.1'

setup(
	name='roo00kie-utils',
	version=str_version,
	author='roo00kie',
	author_email='roo00kie@roo00kie.com',
	url='https://github.com/Ro0kie/roo00kie-utils',
	packages=find_packages(),
	install_requires=[],
)
